#!/bin/bash

source "$2/accept-setup.sh"

# create symlinks

PROGS=(avlcpt cptpg gimplut gimpsvg gplcpt pspsvg pssvg svgx)
WRAPS=(cpt css3 gimp gpt png pov psp qgs sao svg)

mkdir -p bin

for prog in ${PROGS[@]}
do
    ln -s ../../$prog/$prog bin/$prog
done

for wrap in ${WRAPS[@]}
do
    svgwrap="svg$wrap"
    ln -s ../../svgx/wrapper/$svgwrap bin/$svgwrap
done

PATH="./bin:$PATH"

# help

cmd="./gradient-convert --help"
assert_raises "$cmd" 0

# routine conversion tests, we just test that the program returns
# success and a file is created

function check_conversion
{
    iformat="$1"
    ext="$2"
    dir="$3"
    base="$4"

    fixture="$TESTFIX/$dir/$base.$ext"

    for oformat in cpt c3g ggr gpf inc lut pg png psp qgs sao svg
    do
	if [ $iformat = $oformat ] ; then
	    continue
	fi
	output="$base.$oformat"
	cmd="./gradient-convert -i $iformat -o $oformat $fixture $output"
	assert_raises "$cmd" 0
	assert_raises "[ -e $output ]" 0
	rm -f $output
    done
}

check_conversion 'avl' 'avl' 'avl'  'ddvelev1a'
check_conversion 'cpt' 'cpt' 'cpt'  'subtle'
check_conversion 'ggr' 'ggr' 'ggr'  'Sunrise'
check_conversion 'gpl' 'gpl' 'gpl'  'Caramel'
check_conversion 'grd' 'grd' 'grd5' 'my-custom-gradient-3-rgb'
check_conversion 'psp' 'jgd' 'grd3' 'accented'
check_conversion 'svg' 'svg' 'svg'  'lemon-lime'

# tests for other options to do later ...

# clean up the symlinks

for prog in ${PROGS[@]}
do
    rm -f bin/$prog
done

for wrap in ${WRAPS[@]}
do
    svgwrap="svg$wrap"
    rm -f bin/$svgwrap
done

rmdir bin

source accept-teardown.sh
